Module collections

Module collections 

Functions

btreemap_new
Construct an empty BTreeMap.
hashmap_insert
Insert value into map under key, returning the previous value.
hashmap_new
Construct an empty HashMap.
hashmap_with_capacity
Construct a HashMap pre-allocated for at least capacity entries.
hashset_new
Construct an empty HashSet.
insert
Insert value into map under key, returning the previous value.