hashmap_insert

Function hashmap_insert 

pub fn hashmap_insert<K: Eq + Hash, V>(
    map: &mut HashMap<K, V>,
    key: K,
    value: V,
) -> Option<V>
Insert value into map under key, returning the previous value.

Alias of insert with the more explicit hashmap_ prefix used by the other constructors in this module.