Functions
- copy
- Copy
fromtoto. Returns the number of bytes copied. - create_
dir_ all - Create a directory and any missing parents.
- read_
to_ string - Read the entire contents of a file into a
String. - remove_
file - Remove a single file.
- rename
- Rename / move
fromtoto. - write_
bytes - Write a byte buffer to a file.
- write_
text - Write
contentsto a file atpath, creating it if missing and truncating it if it already exists.