Module process

Module process 

Functions

command
Construct a Command that will spawn program.
command_arg
Append a single positional arg to cmd, returning the same cmd for chaining.
command_env
Set an environment variable on cmd, returning the same cmd for chaining.
exit
Terminate the current process with exit status code.