Module fs

Module fs 

Functions

copy
Copy from to to. Returns the number of bytes copied.
create_dir_all
Create a directory and any missing parents.
read_to_string
Read the entire contents of a file into a String.
remove_file
Remove a single file.
rename
Rename / move from to to.
write_bytes
Write a byte buffer to a file.
write_text
Write contents to a file at path, creating it if missing and truncating it if it already exists.